@@ -45,19 +45,8 @@ struct swit {
 extern struct swit anoyes[];	/* standard yes/no switches */
 
 /*
- * folder/messages structure
+ * general folder attributes
  */
-
-/*
- * msgstats[] is a int, so we have 16 or 32 bits to work
- * with.  The first 5 are for standard nmh message flags,
- * this leaves us 11 (or 27) for user-defined attributes.
- * Of these, 1 is reserved for future internal use, so
- * this leaves users 10 (or 26).
- */
-#define	NUMATTRS  ((sizeof(int) * Nbby) - 6)
-
-/* folder attributes */
 #define READONLY  (1<<0)	/* No write access to folder    */
 #define	SEQMOD	  (1<<1)	/* folder's sequences modifed   */
 #define	MHPATH	  (1<<2)	/* mhpath-style folder handling */
@@ -66,21 +55,33 @@ extern struct swit anoyes[];	/* standard yes/no switches */
 
 #define	FBITS "\020\01READONLY\02SEQMOD\03MHPATH\04OTHERS\05MODIFIED"
 
-/* messages attributes */
+/*
+ * type for holding the sequence set of a message
+ */
+typedef unsigned int seqset_t;
+
+/*
+ * Determine the number of user defined sequences we
+ * can have.  The first 5 sequence flags are for
+ * internal nmh message flags.
+ */
+#define	NUMATTRS  ((sizeof(seqset_t) * Nbby) - 5)
+
+/*
+ * first free slot for user defined sequences
+ * and attributes
+ */
+#define	FFATTRSLOT  5
+
+/*
+ * internal messages attributes (sequences)
+ */
 #define EXISTS        (1<<0)	/* exists            */
 #define DELETED       (1<<1)	/* deleted           */
 #define SELECTED      (1<<2)	/* selected for use  */
 #define SELECT_EMPTY  (1<<3)	/* mhpath "new"      */
 #define	UNSEEN        (1<<4)	/* inc/show "unseen" */
 
-/*
- * first free attribute slot for user-defined attributes
- */
-#define	FFATTRSLOT  5
-
-/*
- * first free slot is (1 << 5) or 0x20
- */
 #define	MBITS "\020\01EXISTS\02DELETED\03SELECTED\04NEW\05UNSEEN"
 
 /*
@@ -100,26 +101,29 @@ struct msgs {
     int msgflags;	/* Folder attributes (READONLY, etc) */
     char *foldpath;	/* Pathname of folder                */
 
-    /* name of sequences in this folder */
+    /*
+     * Name of sequences in this folder.  We add an
+     * extra slot, so we can NULL terminate the list.
+     */
     char *msgattrs[NUMATTRS + 1];
 
     /*
      * bit flags for whether sequence
      * is public (0), or private (1)
      */
-    int attrstats;
+    seqset_t attrstats;
 
     int	lowoff;			  /* low element in msgstats[]   */
     int	hghoff;			  /* hgh element in msgstats[]   */
 
     /*
-     * This is an array of integers which we allocate dynamically.
-     * Each integer is a set of bits flags for a particular message
-     * number.  These bit flags represent general attributes
-     * (EXISTS, SELECTED, etc) as well as track if message is
+     * This is an array of seqset_t which we allocate dynamically.
+     * Each seqset_t is a set of bits flags for a particular message.
+     * These bit flags represent general attributes such as
+     * EXISTS, SELECTED, etc. as well as track if message is
      * in a particular sequence.
      */
-    int *msgstats;		/* msg status */
+    seqset_t *msgstats;		/* msg status */
 };
 
 /*
@@ -133,6 +137,10 @@ struct msgs {
  * macros for message and sequence manipulation
  */
 #define clear_msg_flags(mp,msgnum) ((mp)->msgstats[msgnum] = 0)
+#define copy_msg_flags(mp,i,j) \
+	((mp)->msgstats[i] = (mp)->msgstats[j])
+#define get_msg_flags(mp,ptr,msgnum)  (*(ptr) = (mp)->msgstats[msgnum])
+#define set_msg_flags(mp,ptr,msgnum)  ((mp)->msgstats[msgnum] = *(ptr))
 
 #define does_exist(mp,msgnum)     ((mp)->msgstats[msgnum] & EXISTS)
 #define unset_exists(mp,msgnum)   ((mp)->msgstats[msgnum] &= ~EXISTS)
@@ -142,10 +150,17 @@ struct msgs {
 #define unset_selected(mp,msgnum) ((mp)->msgstats[msgnum] &= ~SELECTED)
 #define set_selected(mp,msgnum)   ((mp)->msgstats[msgnum] |= SELECTED)
 
+#define is_select_empty(mp,msgnum) ((mp)->msgstats[msgnum] & SELECT_EMPTY)
+#define set_select_empty(mp,msgnum) \
+	((mp)->msgstats[msgnum] |= SELECT_EMPTY)
+
 #define is_unseen(mp,msgnum)      ((mp)->msgstats[msgnum] & UNSEEN)
 #define unset_unseen(mp,msgnum)   ((mp)->msgstats[msgnum] &= ~UNSEEN)
 #define set_unseen(mp,msgnum)     ((mp)->msgstats[msgnum] |= UNSEEN)
 
+/* for msh only */
+#define set_deleted(mp,msgnum)    ((mp)->msgstats[msgnum] |= DELETED)
+
 #define in_sequence(mp,seqnum,msgnum) \
            ((mp)->msgstats[msgnum] & (1 << (FFATTRSLOT + seqnum)))
 #define clear_sequence(mp,seqnum,msgnum) \
@@ -267,6 +282,7 @@ extern char *mh_seq;
 extern char *mhlformat;
 extern char *mhlforward;
 extern char *mhlproc;
+extern char *mhlreply;
 extern char *moreproc;
 extern char *msgprot;
 extern char *mshproc;
