@@ -24,10 +24,14 @@ struct Cmd {
 #define	MHNCHK 0x0001	/* did nontext check           */
 #define	MHNYES 0x0002	/* .. and known to be non-text */
 
-#define CUR (1 << (FFATTRSLOT + NUMATTRS))
+#define CUR (1 << (FFATTRSLOT + NUMATTRS - 1))
 
 #ifdef BPOP
 # define VIRTUAL SELECT_EMPTY
+
+# define is_virtual(mp,msgnum)    ((mp)->msgstats[msgnum] & VIRTUAL)
+# define unset_virtual(mp,msgnum) ((mp)->msgstats[msgnum] &= ~VIRTUAL)
+# define set_virtual(mp,msgnum)   ((mp)->msgstats[msgnum] |= VIRTUAL)
 #endif
 
 struct Msg {
@@ -35,7 +39,7 @@ struct Msg {
     char *m_scanl;
     struct tws m_tb;
     short m_flags;
-    short m_stats;
+    seqset_t m_stats;
 };
 
 #define	m_bboard_id  m_drop.d_id
@@ -62,8 +66,6 @@ extern FILE *sp;		/* original stdout         */
 extern char *cmd_name;		/* command being run       */
 extern char myfilter[];		/* path to mhl.forward     */
 
-
-
 extern char *BBoard_ID;		/* BBoard-ID constant */
 
 /*
@@ -79,4 +81,3 @@ extern int told_to_quit;	/* SIGQUIT detected */
 extern int should_intr;		/* signal handler should interrupt call */
 extern jmp_buf sigenv;		/* the environment pointer */
 #endif
-
