@@ -96,6 +96,8 @@ int seq_delsel (struct msgs *, char *, int, int);
 int seq_getnum (struct msgs *, char *);
 char *seq_list (struct msgs *, char *);
 int seq_nameok (char *);
+void seq_print (struct msgs *, char *);
+void seq_printall (struct msgs *);
 void seq_read (struct msgs *);
 void seq_save (struct msgs *);
 void seq_setcur (struct msgs *, int);
@@ -136,3 +138,14 @@ char *strerror (int);
 char *LocalName(void);
 char *SystemName(void);
 char *OfficialName(char *);
+
+/*
+ * prototypes for some routines in uip
+ */
+void replout (FILE *, char *, char *, struct msgs *, int,
+	char *, char *, char *);
+int distout (char *, char *, char *);
+int annotate (char *, char *, char *, int, int);
+int what_now (char *, int, int, char *, char *,
+	int, struct msgs *, char *, int, char *);
+
