@@ -21,24 +21,26 @@ static int brkany (char, char *);
 char **
 brkstring (char *strg, char *brksep, char *brkterm)
 {
-    register int bi;
-    register char c, *sp;
+    int i;
+    char c, *sp;
 
-    /* scan string, replacing *
-     * separators with zeroes */
+    /*
+     * scan string, replacing separators with zeroes
+     */
     sp = strg;
 
-    for (bi = 0; bi < MAXARGS; bi++) {
+    for (i = 0; i < MAXARGS; i++) {
 				/* and entering start addrs in "broken" */
 	while (brkany (c = *sp, brksep))
 	    *sp++ = 0;
+
 	if (!c || brkany (c, brkterm)) {
 	    *sp = 0;
-	    broken[bi] = 0;
+	    broken[i] = 0;
 	    return broken;	/* terminator found, finish up */
 	}
 
-	broken[bi] = sp;	/* set next start addr */
+	broken[i] = sp;	/* set next start addr */
 	while ((c = *++sp) && !brkany (c, brksep) && !brkany (c, brkterm))
 		continue;
     }
@@ -54,7 +56,7 @@ brkstring (char *strg, char *brksep, char *brkterm)
 static int
 brkany (char chr, char *strg)
 {
-    register char *sp;
+    char *sp;
 
     if (strg)
 	for (sp = strg; *sp; sp++)
