@@ -10,7 +10,7 @@
 void
 cpydata (int in, int out, char *ifile, char *ofile)
 {
-    register int i;
+    int i;
     char buffer[BUFSIZ];
 
     while ((i = read(in, buffer, sizeof(buffer))) > 0) {
