@@ -418,7 +418,7 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
 		str = "";
 	    break;
 	case FT_LS_MFIND:
-	    if (!(str = m_find (fmt->f_text)))
+	    if (!(str = context_find (fmt->f_text)))
 		str = "";
 	    break;
 	case FT_LS_TRIM:
@@ -606,9 +606,6 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
 	    break;
 	case FT_LS_ADDR:
 	case FT_LS_FRIENDLY:
-#ifdef BERK
-	    str = fmt->f_comp->c_mn->m_mbox;
-#else /* not BERK */
 	    if ((mn = fmt->f_comp->c_mn) == &fmt_mnull) {
 		str = fmt->f_comp->c_text;
 		break;
@@ -650,7 +647,6 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
 			break;
 		  }
 		}
-#endif /* BERK */
 	    break;
 
 	case FT_LOCALDATE:
