@@ -18,11 +18,12 @@ int
 folder_addmsg (struct msgs **mpp, char *msgfile, int selected,
                int unseen, int preserve)
 {
-    int infd, outfd, linkerr, msgnum;
+    int infd, outfd, linkerr, first_time, msgnum;
     char *nmsg, newmsg[BUFSIZ];
     struct msgs *mp;
     struct stat st1, st2;
 
+    first_time = 1;	/* this is first attempt */
     mp = *mpp;
 
     /*
@@ -30,15 +31,18 @@ folder_addmsg (struct msgs **mpp, char *msgfile, int selected,
      * in order to add the message to the folder.
      */
     for (;;) {
-
-	/* should we preserve the numbering of the message? */
-	if (preserve && (msgnum = m_atoi (msgfile)) > 0) {
-	    nmsg = msgfile;
-	    preserve = 0;	/* only try this once */
+	if (first_time) {
+	    /* should we preserve the numbering of the message? */
+	    if (preserve && (msgnum = m_atoi (msgfile)) > 0) {
+		;
+	    } else {
+		/* else use highest message number + 1 */
+		msgnum = mp->hghmsg + 1;
+	    }
+	    first_time = 0;
 	} else {
-	    /* else use the next available number */
-	    msgnum = mp->hghmsg + 1;
-	    nmsg = m_name (msgnum);
+	    /* another attempt, try next higher number */
+	    msgnum++;
 	}
 
 	/*
@@ -85,6 +89,7 @@ folder_addmsg (struct msgs **mpp, char *msgfile, int selected,
 	if (msgnum > mp->hghmsg)
 	    mp->hghmsg = msgnum;
 
+	nmsg = m_name (msgnum);
 	sprintf (newmsg, "%s/%s", mp->foldpath, nmsg);
 
 	/*
