@@ -7,19 +7,25 @@
 
 #include <h/mh.h>
 
+/*
+ * 1) If we are using an external rmmproc, then exec it.
+ * 2) Else if rename_msgs is non-zero, then rename messages by
+ *    prefixing name with standard prefix.
+ * 3) Else unlink SELECTED messages.
+ *
+ * If there is an error, return -1, else return 0.
+ */
+
 int
 folder_delmsgs (struct msgs *mp, int rename_msgs)
 {
     pid_t pid;
-    int msgnum, vecp;
+    int msgnum, vecp, retval = 0;
     char buf[100], *dp, **vec;
 
     for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++) {
 	if (is_selected (mp, msgnum)) {
-	    mp->msgstats[msgnum] &= ~EXISTS;
-#if 0
-	    mp->msgstats[msgnum] |= DELETED;
-#endif
+	    unset_exists (mp, msgnum);
 	}
     }
     mp->msgflags |= SEQMOD;
@@ -33,9 +39,11 @@ folder_delmsgs (struct msgs *mp, int rename_msgs)
 	if (vec == NULL)
 	    adios (NULL, "unable to allocate exec vector");
 	vecp = 1;
-	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	    if (is_selected (mp, msgnum))
-		vec[vecp++] = getcpy (m_name (msgnum));
+	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++) {
+	    if (is_selected (mp, msgnum) &&
+		!(vec[vecp++] = strdup (m_name (msgnum))))
+		adios (NULL, "strdup failed");
+	}
 	vec[vecp] = NULL;
 
 	fflush (stdout);
@@ -64,14 +72,19 @@ folder_delmsgs (struct msgs *mp, int rename_msgs)
 	    if (rename_msgs) {
 		/* rename messages with standard prefix */
 		strcpy (buf, m_backup (dp));
-		if (rename (dp, buf) == NOTOK)
+		if (rename (dp, buf) == NOTOK) {
 		    admonish (buf, "unable to rename %s to", dp);
+		    retval = -1;
+		}
 	    } else {
 		/* or just unlink the selected messages */
-		if (unlink (dp) == NOTOK)
+		if (unlink (dp) == NOTOK) {
 		    admonish (dp, "unable to unlink");
+		    retval = -1;
+		}
 	    }
 	}
     }
-}
 
+    return retval;
+}
