@@ -1,6 +1,6 @@
 
 /*
- * m_draft.c -- construct the draft name
+ * m_draft.c -- construct the name of a draft message
  *
  * $Id$
  */
@@ -20,7 +20,7 @@ m_draft (char *folder, char *msg, int use, int *isdf)
     static char buffer[BUFSIZ];
 
     if (*isdf == NOTOK || folder == NULL || *folder == 0) {
-	if (*isdf == NOTOK || (cp = m_find ("Draft-Folder")) == NULL) {
+	if (*isdf == NOTOK || (cp = context_find ("Draft-Folder")) == NULL) {
 	    *isdf = 0;
 	    return m_maildir (msg && *msg ? msg : draft);
 	}
@@ -46,13 +46,24 @@ m_draft (char *folder, char *msg, int use, int *isdf)
     if (chdir (buffer) == NOTOK)
 	adios (buffer, "unable to change directory to");
 
-    if (!(mp = m_readfolder (folder)))
+    if (!(mp = folder_read (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
-    if ((mp = m_remsg (mp, 0, MAXFOLDER)) == NULL)
+    /*
+     * Make sure we have enough message space for the "new"
+     * sequence.  If not, then add space for 100 messages.
+     */
+    if ((mp->hghmsg >= mp->hghoff) &&
+	!(mp = folder_realloc (mp, 0, mp->hghmsg + 100)))
 	adios (NULL, "unable to allocate folder storage");
+
     mp->msgflags |= MHPATH;
 
+    /*
+     * If we have been give a valid message name, then use that.
+     * Else, if we are given the "use" option, then use the
+     * current message.  Else, use special sequence "new".
+     */
     if (!m_convert (mp, msg && *msg ? msg : use ? "cur" : "new"))
 	done (1);
     seq_setprev (mp);
@@ -65,7 +76,7 @@ m_draft (char *folder, char *msg, int use, int *isdf)
 
     seq_setcur (mp, mp->lowsel);/* set current message for folder */
     seq_save (mp);		/* synchronize message sequences  */
-    m_freefolder (mp);		/* free folder/message info       */
+    folder_free (mp);		/* free folder/message structure  */
 
     return cp;
 }
