@@ -13,5 +13,5 @@ m_gmprot (void)
 {
     register char *cp;
 
-    return atooi ((cp = m_find ("msg-protect")) && *cp ? cp : msgprot);
+    return atooi ((cp = context_find ("msg-protect")) && *cp ? cp : msgprot);
 }
