@@ -34,7 +34,7 @@ pidwait (pid_t id, int sigsok)
     }
 
 #ifdef HAVE_WAITPID
-    pid = waitpid(id, &status, WUNTRACED);
+    pid = waitpid(id, &status, 0);
 #else
     while ((pid = wait(&status)) != NOTOK && pid != id)
 	continue;
