@@ -1,7 +1,7 @@
 
 /*
  * refile.c -- call the "fileproc" to refile the
- *          -- draft into another folder
+ *          -- msg or draft into another folder
  *
  * $Id$
  */
@@ -29,7 +29,7 @@ refile (char **arg, char *file)
     }
     vec[vecp] = NULL;
 
-    m_update();		/* update the context file */
+    context_save();	/* save the context file */
     fflush(stdout);
 
     switch (pid = vfork()) {
