@@ -21,7 +21,7 @@ seq_setprev (struct msgs *mp)
     register char *cp, *dp, **ap;
 
     dp = NULL;
-    if ((cp = m_find (psequence)) == NULL
+    if ((cp = context_find (psequence)) == NULL
 	    || (ap = brkstring (dp = getcpy (cp), " ", "\n")) == NULL
 	    || *ap == NULL) {
 	if (dp)
