@@ -42,15 +42,15 @@ annotate (char *file, char *comp, char *text, int inplace, int datesw)
 
 
 static int
-annosbr (int src, char *file, char *comp, char *text, int inplace, int datesw)
+annosbr (int fd, char *file, char *comp, char *text, int inplace, int datesw)
 {
-    int mode, fd;
-    register char *cp, *sp;
+    int mode, tmpfd;
+    char *cp, *sp;
     char buffer[BUFSIZ], tmpfil[BUFSIZ];
     struct stat st;
-    register FILE *tmp;
+    FILE *tmp;
 
-    mode = fstat (src, &st) != NOTOK ? (st.st_mode & 0777) : m_gmprot ();
+    mode = fstat (fd, &st) != NOTOK ? (st.st_mode & 0777) : m_gmprot ();
 
     strcpy (tmpfil, m_scratch (file, "annotate"));
 
@@ -76,15 +76,15 @@ annosbr (int src, char *file, char *comp, char *text, int inplace, int datesw)
 	    putc ('\n', tmp);
     }
     fflush (tmp);
-    cpydata (src, fileno (tmp), file, tmpfil);
+    cpydata (fd, fileno (tmp), file, tmpfil);
     fclose (tmp);
 
     if (inplace) {
-	if ((fd = open (tmpfil, O_RDONLY)) == NOTOK)
+	if ((tmpfd = open (tmpfil, O_RDONLY)) == NOTOK)
 	    adios (tmpfil, "unable to open for re-reading");
-	lseek (src, (off_t) 0, SEEK_SET);
-	cpydata (fd, src, tmpfil, file);
-	close (fd);
+	lseek (fd, (off_t) 0, SEEK_SET);
+	cpydata (tmpfd, fd, tmpfil, file);
+	close (tmpfd);
 	unlink (tmpfil);
     } else {
 	strcpy (buffer, m_backup (file));
