@@ -186,7 +186,7 @@ main (int argc, char **argv)
     if (popbbuser && *popbbuser)
 	user = popbbuser, rpop = 0;
 #endif	BPOP
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     }
@@ -303,7 +303,7 @@ main (int argc, char **argv)
 	setuid (getuid ());
 #endif	BPOP
 
-    if (!m_find ("path"))
+    if (!context_find ("path"))
 	free (path ("./", TFOLDER));
 
     rcinit (rc);
@@ -422,7 +422,7 @@ printb (unsigned int flags)
 {
     char buffer[BUFSIZ];
 
-    printv ("Flags", sprintb (buffer, flags, BBITS));
+    printv ("Flags", snprintb (buffer, BUFSIZ, flags, BBITS));
 }
 
 
@@ -876,7 +876,7 @@ default_bboards () {
     if (bbl != NULL)
 	return;
 
-    if (!archivesw && ((cp = m_find ("bboards")) != NULL)) {
+    if (!archivesw && ((cp = context_find ("bboards")) != NULL)) {
 #ifndef	BPOP
 	for (ap = brkstring (cp = getcpy (cp), " ", "\n"); *ap; ap++)
 #else	BPOP
