@@ -300,7 +300,7 @@ burst (struct msgs **mpp, int msgnum, struct smsg *smsgs, int numburst,
 
 		if (rename (f2, f1) == NOTOK)
 		    admonish (f1, "unable to rename %s to", f2);
-		mp->msgstats[i] = mp->msgstats[j];
+		copy_msg_flags (mp, i, j);
 		clear_msg_flags (mp, j);
 		mp->msgflags |= SEQMOD;
 	    }
@@ -332,7 +332,7 @@ burst (struct msgs **mpp, int msgnum, struct smsg *smsgs, int numburst,
 	}
 	if (rename (f2, f1) == NOTOK)
 	    admonish (f1, "unable to rename %s to", f2);
-	mp->msgstats[i] = mp->msgstats[msgnum];
+	copy_msg_flags (mp, i, msgnum);
 	mp->msgflags |= SEQMOD;
     }
 
