@@ -90,7 +90,7 @@ main (int argc, char **argv)
     argp = arguments;
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, switches);
@@ -163,6 +163,7 @@ main (int argc, char **argv)
 		    isdf = NOTOK;
 		    continue;
 	    }
+	}
 	if (*cp == '+' || *cp == '@') {
 	    if (folder)
 		adios (NULL, "only one folder at a time!");
@@ -181,6 +182,7 @@ main (int argc, char **argv)
     if (!context_find ("path"))
 	free (path ("./", TFOLDER));
 
+    /* Check if we are using a draft folder */
     if ((dfolder || context_find ("Draft-Folder")) && !folder && msg && !file) {
 	file = msg;
 	msg = NULL;
@@ -189,6 +191,9 @@ main (int argc, char **argv)
 	    adios (NULL, "can't mix forms and folders/msgs");
 
     if (folder || msg) {
+	/*
+	 * Use a message as the "form" for the new message.
+	 */
 	if (!msg)
 	    msg = "cur";
 	if (!folder)
@@ -216,6 +221,9 @@ main (int argc, char **argv)
 	if ((in = open (form = getcpy (m_name (mp->lowsel)), O_RDONLY)) == NOTOK)
 	    adios (form, "unable to open message");
     } else {
+	/*
+	 * Open a component or forms file
+	 */
 	if (form) {
 	    if ((in = open (etcpath (form), O_RDONLY)) == NOTOK)
 		adios (form, "unable to open form file");
@@ -228,9 +236,19 @@ main (int argc, char **argv)
 
 try_it_again: ;
     strcpy (drft, m_draft (dfolder, file, use, &isdf));
+
+    /*
+     * Check if we have an existing draft
+     */
     if ((out = open (drft, O_RDONLY)) != NOTOK) {
 	i = fdcompare (in, out);
 	close (out);
+
+	/*
+	 * If we have given -use flag, or if the
+	 * draft is just the same as the components
+	 * file, then no need to ask any questions.
+	 */
 	if (use || i)
 	    goto edit_it;
 
@@ -264,10 +282,10 @@ try_it_again: ;
 		    break;
 	    }
 	}
-    }
-    else
+    } else {
 	if (use)
 	    adios (drft, "unable to open");
+    }
 
     if ((out = creat (drft, m_gmprot ())) == NOTOK)
 	adios (drft, "unable to create");
