@@ -12,7 +12,15 @@
 #include <grp.h>
 #include <pwd.h>
 
+/*
+ * maximum number of directories that can
+ * be specified using -search switch.
+ */
 #define	NDIRS	100
+
+/*
+ * Add space for group names, 100 at a time
+ */
 #define	NGRPS	100
 
 static struct swit switches[] = {
@@ -59,7 +67,10 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    m_foil (NULL);		/* foil search of user profile */
+
+    /* foil search of user profile/context */
+    if (context_foil (NULL) == -1)
+	done (1);
     mts_init (invo_name);
 
     while ((cp = *argp++)) {
@@ -149,7 +160,7 @@ pwd_names (void)
 	    if (strcmp (hm->h_name, lm->h_name) == 0) {
 		setup ();
 		fprintf (out, "duplicate user %s(uid=%d)\n",
-			lm->h_name, lm->h_uid);
+			lm->h_name, (int) lm->h_uid);
 		hit++;
 	    }
 
@@ -161,37 +172,42 @@ pwd_names (void)
 void
 grp_names (void)
 {
-    register int gp, hit = 0;
-    char *grps[NGRPS];
-    register struct group  *gr;
+    int numgroups, maxgroups;
+    int i, hit = 0;
+    char **grps;
+    struct group *gr;
+
+    /* allocate space NGRPS at a time */
+    numgroups = 0;
+    maxgroups = NGRPS;
+    if (!(grps = (char **) malloc((size_t) (maxgroups * sizeof(*grps)))))
+	adios (NULL, "unable to allocate group name storage");
 
-    grps[0] = NULL;
     setgrent ();
-    while (gr = getgrent ()) {
-	for (gp = 0; grps[gp]; gp++)
-	    if (strcmp (grps[gp], gr->gr_name) == 0) {
+    while ((gr = getgrent ())) {
+	for (i = 0; i < numgroups; i++)
+	    if (!strcmp (grps[i], gr->gr_name)) {
 		setup ();
 		fprintf (out, "duplicate group %s(gid=%d)\n",
-			gr->gr_name, gr->gr_gid);
+			gr->gr_name, (int) gr->gr_gid);
 		hit++;
 		break;
 	    }
-	if (grps[gp] == NULL)
-	    if (gp < NGRPS) {
-		grps[gp++] = getcpy (gr->gr_name);
-		grps[gp] = NULL;
-	    }
-	    else {
-		setup ();
-		fprintf (out, "more than %d groups (time to recompile)\n",
-			NGRPS - 1);
-		hit++;
+	if (i >= numgroups) {
+	    if (numgroups >= maxgroups) {
+		maxgroups += NGRPS;
+		if (!(grps = (char **) realloc(grps,
+			(size_t) (maxgroups * sizeof(*grps)))))
+		    adios (NULL, "unable to rellocate group name storage");
 	    }
+	    grps[numgroups++] = getcpy (gr->gr_name);
+	}
     }
     endgrent ();
 
-    for (gp = 0; grps[gp]; gp++)
-	free (grps[gp]);
+    for (i = 0; i < numgroups; i++)
+	free (grps[i]);
+    free (grps);
 
     if (!hit && out && !mail)
 	fprintf (out, "no duplicate groups\n");
@@ -207,7 +223,7 @@ grp_members (void)
     register struct home  *hm;
 
     setgrent ();
-    while (gr = getgrent ())
+    while ((gr = getgrent ())) {
 	for (cp = gr->gr_mem; *cp; cp++) {
 	    for (hm = homehead; hm; hm = hm->h_next)
 		if (!strcmp (*cp, hm->h_name))
@@ -215,33 +231,30 @@ grp_members (void)
 	    if (hm == NULL) {
 		setup ();
 		fprintf (out, "group %s(gid=%d) has unknown member %s\n",
-			gr->gr_name, gr->gr_gid, *cp);
+			gr->gr_name, (int) gr->gr_gid, *cp);
 		hit++;
-	    }
-#ifdef BSD42
-	    else
+	    } else {
 		hm->h_ngrps++;
-#endif /* BSD42 */
+	    }
 
 	    for (dp = cp + 1; *dp; dp++)
 		if (strcmp (*cp, *dp) == 0) {
 		    setup ();
 		    fprintf (out, "group %s(gid=%d) has duplicate member %s\n",
-			    gr->gr_name, gr->gr_gid, *cp);
+			    gr->gr_name, (int) gr->gr_gid, *cp);
 		    hit++;
 		}
 	}
+    }
     endgrent ();
 
-#ifdef BSD42
     for (hm = homehead; hm; hm = hm->h_next)
-	if (hm->h_ngrps > NGROUPS) {
+	if (hm->h_ngrps > NGROUPS_MAX) {
 	    setup ();
-	    fprintf (out, "user %s is a member of %d groups (max %d)",
-		    hm->h_name, hm->h_ngrps, NGROUPS);
+	    fprintf (out, "user %s is a member of %d groups (max %d)\n",
+		    hm->h_name, hm->h_ngrps, NGROUPS_MAX);
 	    hit++;
 	}
-#endif /* BSD42 */
 
     if (!hit && out && !mail)
 	fprintf (out, "all group members accounted for\n");
@@ -258,7 +271,7 @@ grp_ids (void)
 	if (getgrgid (hm->h_gid) == NULL) {
 	    setup ();
 	    fprintf (out, "user %s(uid=%d) has unknown group-id %d\n",
-		    hm->h_name, hm->h_uid, hm->h_gid);
+		    hm->h_name, (int) hm->h_uid, (int) hm->h_gid);
 	    hit++;
 	}
 
@@ -294,7 +307,7 @@ mdrop(char *drop)
 	return;
     }
 
-    while (dp = readdir (dd))
+    while ((dp = readdir (dd)))
 	if (dp->d_name[0] != '.' && !check (dp->d_name)) {
 	    setup ();
 	    fprintf (out,
