@@ -82,17 +82,17 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = context_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name))) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, switches);
@@ -171,17 +171,18 @@ main (int argc, char **argv)
 		    isdf = NOTOK;
 		    continue;
 	    }
+	}
 	if (*cp == '+' || *cp == '@') {
 	    if (folder)
 		adios (NULL, "only one folder at a time!");
 	    else
 		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
-	}
-	else
+	} else {
 	    if (msg)
 		adios (NULL, "only one message at a time!");
 	    else
 		msg = cp;
+	}
     }
 
     cwd = getcpy (pwd ());
@@ -202,6 +203,8 @@ main (int argc, char **argv)
 
 try_it_again: ;
     strcpy (drft, m_draft (dfolder, dmsg, NOUSE, &isdf));
+
+    /* Check if draft already exists */
     if (stat (drft, &st) != NOTOK) {
 	printf ("Draft \"%s\" exists (%ld bytes).", drft, st.st_size);
 	for (i = LISTDSW; i != YESW;) {
@@ -236,34 +239,38 @@ try_it_again: ;
     close (out);
 
     if (file) {
-	anot = 0;
-	goto go_to_it;
+	/*
+	 * Dist a file
+	 */
+	anot = 0;	/* don't want to annotate a file */
+    } else {
+	/*
+	 * Dist a message
+	 */
+	if (!msg)
+	    msg = "cur";
+	if (!folder)
+	    folder = getfolder (1);
+	maildir = m_maildir (folder);
+
+	if (chdir (maildir) == NOTOK)
+	    adios (maildir, "unable to change directory to");
+	if (!(mp = folder_read (folder)))
+	    adios (NULL, "unable to read folder %s", folder);
+	if (mp->hghmsg == 0)
+	    adios (NULL, "no messages in %s", folder);
+
+	/* parse the message range/sequence/name and set SELECTED */
+	if (!m_convert (mp, msg))
+	    done (1);
+	seq_setprev (mp);	/* set the previous-sequence */
+
+	if (mp->numsel > 1)
+	    adios (NULL, "only one message at a time!");
     }
 
-    if (!msg)
-	msg = "cur";
-    if (!folder)
-	folder = getfolder (1);
-    maildir = m_maildir (folder);
-
-    if (chdir (maildir) == NOTOK)
-	adios (maildir, "unable to change directory to");
-    if (!(mp = folder_read (folder)))
-	adios (NULL, "unable to read folder %s", folder);
-    if (mp->hghmsg == 0)
-	adios (NULL, "no messages in %s", folder);
-
-    /* parse the message range/sequence/name and set SELECTED */
-    if (!m_convert (mp, msg))
-	done (1);
-    seq_setprev (mp);	/* set the previous-sequence */
-
-    if (mp->numsel > 1)
-	adios (NULL, "only one message at a time!");
-
-go_to_it: ;
-    if ((in = open (msgnam = file ? file : getcpy (m_name (mp->lowsel)), O_RDONLY))
-	    == NOTOK)
+    msgnam = file ? file : getcpy (m_name (mp->lowsel));
+    if ((in = open (msgnam, O_RDONLY)) == NOTOK)
 	adios (msgnam, "unable to open message");
 
     if (!file) {
