@@ -114,9 +114,10 @@ static struct msgs *mp = NULL;		/* used a lot */
 /*
  * static prototypes
  */
-static int build_form (char *, char *, int, int);
-static void copy_draft (int, char *, char *, int, int, int);
 static void mhl_draft(int, char *, int, int, char *, char *, int);
+static void copy_draft (int, char *, char *, int, int);
+static void copy_mime_draft (int);
+static int build_form (char *, char *, int, int);
 
 
 int
@@ -141,17 +142,17 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = context_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name))) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, switches);
@@ -282,14 +283,15 @@ main (int argc, char **argv)
 		    dashflg = 0;
 		    continue;
 	    }
+	}
 	if (*cp == '+' || *cp == '@') {
 	    if (folder)
 		adios (NULL, "only one folder at a time!");
 	    else
 		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
-	}
-	else
+	} else {
 	    msgs[msgp++] = cp;
+	}
     }
 
     cwd = getcpy (pwd ());
@@ -300,13 +302,18 @@ main (int argc, char **argv)
 	adios (NULL, "can't mix files and folders/msgs");
 
 try_it_again: ;
-#ifndef MHE
-    strcpy (drft, m_draft (dfolder, dmsg, NOUSE, &isdf));
-    if (stat (drft, &st) != NOTOK) {
-#else	/* MHE */
+
+#ifdef MHE
     strcpy (drft, buildsw ? m_maildir ("draft")
 			  : m_draft (dfolder, NULL, NOUSE, &isdf));
+
+    /* Check if a draft already exists */
     if (!buildsw && stat (drft, &st) != NOTOK) {
+#else
+    strcpy (drft, m_draft (dfolder, dmsg, NOUSE, &isdf));
+
+    /* Check if a draft already exists */
+    if (stat (drft, &st) != NOTOK) {
 #endif	/* MHE */
 	printf ("Draft \"%s\" exists (%ld bytes).", drft, (long) st.st_size);
 	for (i = LISTDSW; i != YESW;) {
@@ -335,33 +342,40 @@ try_it_again: ;
     }
 
     if (file) {
-	anot = 0;
-	goto go_to_it;
+	/*
+	 * Forwarding a file.
+         */
+	anot = 0;	/* don't want to annotate a file */
+    } else {
+	/*
+	 * Forwarding a message.
+	 */
+	if (!msgp)
+	    msgs[msgp++] = "cur";
+	if (!folder)
+	    folder = getfolder (1);
+	maildir = m_maildir (folder);
+
+	if (chdir (maildir) == NOTOK)
+	    adios (maildir, "unable to change directory to");
+	if (!(mp = folder_read (folder)))
+	    adios (NULL, "unable to read folder %s", folder);
+	if (mp->hghmsg == 0)
+	    adios (NULL, "no messages in %s", folder);
+
+	/* parse all the message ranges/sequences and set SELECTED */
+	for (msgnum = 0; msgnum < msgp; msgnum++)
+	    if (!m_convert (mp, msgs[msgnum]))
+		done (1);
+	seq_setprev (mp);	/* set the previous sequence */
     }
 
-    if (!msgp)
-	msgs[msgp++] = "cur";
-    if (!folder)
-	folder = getfolder (1);
-    maildir = m_maildir (folder);
-
-    if (chdir (maildir) == NOTOK)
-	adios (maildir, "unable to change directory to");
-    if (!(mp = folder_read (folder)))
-	adios (NULL, "unable to read folder %s", folder);
-    if (mp->hghmsg == 0)
-	adios (NULL, "no messages in %s", folder);
-
-    /* parse all the message ranges/sequences and set SELECTED */
-    for (msgnum = 0; msgnum < msgp; msgnum++)
-	if (!m_convert (mp, msgs[msgnum]))
-	    done (1);
-    seq_setprev (mp);	/* set the previous sequence */
-
-go_to_it: ;
     if (filter && access (filter, R_OK) == NOTOK)
 	adios (filter, "unable to read");
 
+    /*
+     * Open form (component) file.
+     */
     if (digest) {
 	if (issue == 0) {
 	    sprintf (buf, IFORMAT, digest);
@@ -378,54 +392,63 @@ go_to_it: ;
 	if (!form)
 	    form = digestcomps;
 	in = build_form (form, digest, volume, issue);
-    }
-    else
+    } else {
 	if (form) {
 	    if ((in = open (etcpath (form), O_RDONLY)) == NOTOK)
 		adios (form, "unable to open form file");
-	}
-	else {
+	} else {
 	    if ((in = open (etcpath (forwcomps), O_RDONLY)) == NOTOK)
 		adios (forwcomps, "unable to open default components file");
 	    form = forwcomps;
 	}
+    }
 
     if ((out = creat (drft, m_gmprot ())) == NOTOK)
 	adios (drft, "unable to create");
 
+    /*
+     * copy the components into the draft
+     */
     cpydata (in, out, form, drft);
     close (in);
 
     if (file) {
+	/* just copy the file into the draft */
 	if ((in = open (file, O_RDONLY)) == NOTOK)
 	    adios (file, "unable to open");
 	cpydata (in, out, file, drft);
 	close (in);
 	close (out);
-	goto edit_it;
+    } else {
+	/*
+	 * If filter file is defined, the format the
+	 * messages into the draft using mhlproc.
+	 */
+	if (filter)
+	    mhl_draft (out, digest, volume, issue, drft, filter, dashflg);
+#ifdef MIME
+	else if (mime)
+	    copy_mime_draft (out);
+#endif
+	else
+	    copy_draft (out, digest, drft, volume, issue);
+	close (out);
+
+	if (digest) {
+	    sprintf (buf, IFORMAT, digest);
+	    sprintf (value, "%d", issue);
+	    context_replace (buf, getcpy (value));
+	    sprintf (buf, VFORMAT, digest);
+	    sprintf (value, "%d", volume);
+	    context_replace (buf, getcpy (value));
+	}
+
+	context_replace (pfolder, folder);	/* update current folder   */
+	seq_setcur (mp, mp->lowsel);		/* update current message  */
+	seq_save (mp);				/* synchronize sequences   */
+	context_save ();			/* save the context file   */
     }
 
-    if (filter)
-	mhl_draft (out, digest, volume, issue, drft, filter, dashflg);
-    else
-	copy_draft (out, digest, drft, volume, issue, mime);
-    close (out);
-
-    if (digest) {
-	sprintf (buf, IFORMAT, digest);
-	sprintf (value, "%d", issue);
-	context_replace (buf, getcpy (value));
-	sprintf (buf, VFORMAT, digest);
-	sprintf (value, "%d", volume);
-	context_replace (buf, getcpy (value));
-    }
-
-    context_replace (pfolder, folder);	/* update current folder   */
-    seq_setcur (mp, mp->lowsel);	/* update current message  */
-    seq_save (mp);			/* synchronize sequences   */
-    context_save ();			/* save the context file   */
-
-edit_it: ;
     if (nwhat)
 	done (0);
     what_now (ed, nedit, NOUSE, drft, NULL, 0, mp,
@@ -434,6 +457,12 @@ edit_it: ;
 }
 
 
+/*
+ * Filter the messages you are forwarding, into the
+ * draft calling the mhlproc, and reading its output
+ * from a pipe.
+ */
+
 static void
 mhl_draft  (int out, char *digest, int volume, int issue,
             char *file, char *filter, int dashflg)
@@ -496,29 +525,18 @@ mhl_draft  (int out, char *digest, int volume, int issue,
 }
 
 
+/*
+ * Copy the messages into the draft.  The messages are
+ * bit-stuffed, but not filtered through the mhlproc.
+ */
+
 static void
-copy_draft (int out, char *digest, char *file, int volume, int issue, int mime)
+copy_draft (int out, char *digest, char *file, int volume, int issue)
 {
     int fd,i, msgcnt, msgnum;
     register char *bp, *msgnam;
     char buffer[BUFSIZ];
 
-#ifdef MIME
-    if (mime) {
-	sprintf (buffer, "#forw [forwarded message%s] +%s",
-		 mp->numsel == 1 ? "" : "s", mp->foldpath);
-	write (out, buffer, strlen (buffer));
-	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	    if (is_selected (mp, msgnum)) {
-		sprintf (buffer, " %s", m_name (msgnum));
-		write (out, buffer, strlen (buffer));
-	    }
-	write (out, "\n", 1);
-
-	return;
-    }
-#endif /* MIME */
-
     msgcnt = 1;
     for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++) {
 	if (is_selected (mp, msgnum)) {
@@ -565,6 +583,30 @@ copy_draft (int out, char *digest, char *file, int volume, int issue, int mime)
 }
 
 
+#ifdef MIME
+/*
+ * Create a mhn composition file for forwarding message.
+ */
+
+static void
+copy_mime_draft (int out)
+{
+    int msgnum;
+    char buffer[BUFSIZ];
+
+    sprintf (buffer, "#forw [forwarded message%s] +%s",
+	mp->numsel == 1 ? "" : "s", mp->foldpath);
+    write (out, buffer, strlen (buffer));
+    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
+	if (is_selected (mp, msgnum)) {
+	    sprintf (buffer, " %s", m_name (msgnum));
+	    write (out, buffer, strlen (buffer));
+	}
+    write (out, "\n", 1);
+}
+#endif /* MIME */
+
+
 static int
 build_form (char *form, char *digest, int volume, int issue)
 {
