@@ -38,8 +38,6 @@ static struct swit switches[] = {
 /*
  * static prototypes
  */
-static void seq_printall (struct msgs *);
-static void seq_print (struct msgs *, char *);
 static void print_debug (struct msgs *);
 static void seq_printdebug (struct msgs *);
 
@@ -203,11 +201,13 @@ main (int argc, char **argv)
 
     /* Listing messages in sequences */
     if (listsw) {
-	if (!seqp) {
-	    seq_printall (mp);
-	} else {
+	if (seqp) {
+	    /* print the sequences given */
 	    for (seqp = 0; seqs[seqp]; seqp++)
 		seq_print (mp, seqs[seqp]);
+	} else {
+	    /* else print them all */
+	    seq_printall (mp);
 	}
 
 	/* print debugging info about SELECTED messages */
@@ -223,40 +223,6 @@ main (int argc, char **argv)
 }
 
 
-#define empty(s) ((s) ? (s) : "")
-
-/*
- * Print all the sequences in a folder
- */
-static void
-seq_printall (struct msgs *mp)
-{
-    int i;
-
-    for (i = 0; mp->msgattrs[i]; i++)
-	printf ("%s%s: %s\n", mp->msgattrs[i],
-	    is_seq_private (mp, i) ? " (private)" : "",
-	    empty(seq_list(mp, mp->msgattrs[i])));
-}
-
-
-/*
- * Print a particular sequence in a folder
- */
-static void
-seq_print (struct msgs *mp, char *seqname)
-{
-    int i;
-
-    /* get the index of sequence */
-    i = seq_getnum (mp, seqname);
-
-    printf ("%s%s: %s\n", seqname,
-	(i == -1) ? "" : is_seq_private(mp, i) ? " (private)" : "",
-	empty(seq_list(mp, seqname)));
-}
-
-
 /*
  * Print general debugging info
  */
