@@ -297,8 +297,10 @@ mhl (int argc, char **argv)
     char buf[80], *arguments[MAXARGS], *files[MAXARGS];
 
     invo_name = r1bindex (argv[0], '/');
+
     if ((cp = getenv ("MHLDEBUG")) && *cp)
 	mhldebug++;
+
     if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
@@ -313,7 +315,7 @@ mhl (int argc, char **argv)
 
     vecp = 0;
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, mhlswitches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, mhlswitches);
@@ -421,6 +423,7 @@ mhl (int argc, char **argv)
 		    dobody = 0;
 		    continue;
 	    }
+	}
 	files[vecp++] = cp;
     }
 
@@ -428,7 +431,7 @@ mhl (int argc, char **argv)
 	folder = getenv ("mhfolder");
 
     if (isatty (fileno (stdout))) {
-	if (!nomore && !sc_hardcopy() && moreproc && *moreproc) {
+	if (!nomore && !sc_hardcopy() && moreproc && *moreproc != '\0') {
 	    if (mhl_action) {
 		SIGNAL (SIGINT, SIG_IGN);
 		SIGNAL2 (SIGQUIT, quitser);
@@ -579,7 +582,7 @@ mhl_format (char *file, int length, int width)
     }
     fclose (fp);
 
-    if (mhldebug)
+    if (mhldebug) {
 	for (c1 = fmthd; c1; c1 = c1->c_next) {
 	    fprintf (stderr, "c1: name=\"%s\" text=\"%s\" ovtxt=\"%s\"\n",
 		    c1->c_name, c1->c_text, c1->c_ovtxt);
@@ -591,13 +594,15 @@ mhl_format (char *file, int length, int width)
 	    fprintf (stderr, "\tflags=%s\n",
 		    snprintb (buffer, BUFSIZ, (unsigned) c1->c_flags, LBITS));
 	}
+    }
 
 out: ;
-    if (clearflg == 1)
+    if (clearflg == 1) {
 	global.c_flags |= CLEARSCR;
-    else
+    } else {
 	if (clearflg == -1)
 	    global.c_flags &= ~CLEARSCR;
+    }
 
     switch (bellflg) {		/* command line may override format file */
 	case 1: 
@@ -717,10 +722,11 @@ static char *
 parse (void)
 {
     int c;
-    register char *cp;
+    char *cp;
     static char result[NAMESZ];
 
-    for (cp = result; c = *parptr; parptr++) {
+    for (cp = result; *parptr; parptr++) {
+	c = *parptr;
 	if (isalnum (c)
 		|| c == '.'
 		|| c == '-'
