@@ -17,16 +17,18 @@ char *sbackup = BACKUP_PREFIX;
 char *slink = LINK;
 
 static struct swit switches[] = {
-#define	COMPSW	0
+#define	COMPSW	  0
     { "components", 0 },
-#define	NCOMPSW	1
+#define	NCOMPSW	  1
     { "nocomponents", 0 },
-#define	ALLSW	2
+#define	ALLSW	  2
     { "all", 0 },
 #define VERSIONSW 3
     { "version", 0 },
-#define	HELPSW	4
+#define	HELPSW	  4
     { "help", 4 },
+#define DEBUGSW   5
+    { "debug", -5 },
     { NULL, 0 }
 };
 
@@ -78,23 +80,24 @@ static char *p_find(char *);
 int
 main(int argc, char **argv)
 {
-    int i, all = 0, compp = 0;
-    int components = -1, missed = 0;
+    int i, compp = 0, missed = 0;
+    int all = 0, debug = 0;
+    int components = -1;
     char *cp, buf[100], **ap, **argp;
     char *arguments[MAXARGS], *comps[MAXARGS];
 
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = context_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name))) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, switches);
@@ -121,13 +124,17 @@ main(int argc, char **argv)
 		    all = 1;
 		    break;
 
+		case DEBUGSW:
+		    debug = 1;
+		    break;
 	    }
-	else 
+	} else {
 	    comps[compp++] = cp;
+	}
     }
 
     if (all) {
-        register struct node *np;
+        struct node *np;
 
 	if (compp)
 	    advise(NULL, "profile-components ignored with -all");
@@ -139,7 +146,19 @@ main(int argc, char **argv)
 	/* print all entries in context/profile list */
 	context_read();
 	for (np = m_defs; np; np = np->n_next)
-	    printf("%s:\t%s\n", np->n_name, np->n_field);
+	    printf("%s: %s\n", np->n_name, np->n_field);
+
+    } if (debug) {
+	struct proc *ps;
+
+	/*
+	 * Print the current value of everything in
+	 * procs array.  This will show their current
+	 * value (as determined after context is read).
+         */
+	for (ps = procs; ps->p_name; ps++)
+	    printf ("%s: %s\n", ps->p_name, *ps->p_field ? *ps->p_field : "");
+
     } else {
         if (components < 0)
 	    components = compp > 1;
@@ -152,7 +171,7 @@ main(int argc, char **argv)
 		value = p_find (comps[i]);
 	    if (value) {
 	        if (components)
-		    printf("%s:\t", comps[i]);
+		    printf("%s: ", comps[i]);
 
 		printf("%s\n", value);
 	    } else
@@ -167,7 +186,7 @@ main(int argc, char **argv)
 static char *
 p_find(char *str)
 {
-    register struct proc *ps;
+    struct proc *ps;
 
     for (ps = procs; ps->p_name; ps++)
 	if (uleq (ps->p_name, str))
