@@ -93,14 +93,17 @@ int
 main (int argc, char **argv)
 {
     int datesw = 1, notifysw = NT_ALL;
-    int rpop = 0, status = 0;
-    int vecp = 0, snoop = 0;
+    int rpop = 0, status = 0, vecp = 0;
     uid_t uid;
     char *cp, *host = NULL, buf[80], **ap;
     char **argp, *arguments[MAXARGS], *vec[50];
     char *user;
     struct passwd *pw;
 
+#ifdef POP
+    int snoop = 0;
+#endif
+
 #ifdef HESIOD
     struct hes_postoffice *po;
     char *tmphost;
