@@ -760,6 +760,7 @@ setup (char *file)
 
     if (!(mp = (struct msgs  *) calloc ((size_t) 1, sizeof(*mp))))
 	padios (NULL, "unable to allocate folder storage");
+
     if (!(mp->msgstats = calloc ((size_t) 1, msgp + 3)))
 	padios (NULL, "unable to allocate message status storage");
 
@@ -790,19 +791,25 @@ setup (char *file)
 #ifndef	NNTP
 	for (i = mp->lowmsg; i <= mp->hghmsg; i++) {
 	    Msgs[i].m_top = i;
-	    mp->msgstats[i] = EXISTS | VIRTUAL;
+	    clear_msg_flags (mp, i);
+	    set_exists (mp, i);
+	    set_virtual (mp, i);
 	}
 #else /* NNTP */
 	for (i = mp->lowmsg; i <= mp->hghmsg; i++) {
 	    if (Msgs[i].m_top)			/* set in read_pop() */
-		mp->msgstats[i] = EXISTS | VIRTUAL;
+		clear_msg_flags (mp, i);
+		set_exists (mp, i);
+		set_virtual (mp, i);
 	}
 #endif /* NNTP */
     }
     else
 #endif	/* BPOP */
-    for (i = mp->lowmsg; i <= mp->hghmsg; i++)
-	mp->msgstats[i] = EXISTS;
+    for (i = mp->lowmsg; i <= mp->hghmsg; i++) {
+	clear_msg_flags (mp, i);
+	set_exists (mp, i);
+    }
     m_init ();
 
     mp->msgattrs[0] = getcpy ("unseen");
@@ -988,7 +995,7 @@ msh_ready (int msgnum, int full)
     }
 
 #ifdef BPOP
-    if (pmsh && (mp->msgstats[msgnum] & VIRTUAL)) {
+    if (pmsh && is_virtual (mp, msgnum)) {
 	if (Msgs[msgnum].m_top == 0)
 	    padios (NULL, "msh_ready (%d, %d) botch", msgnum, full);
 	if (!full) {
@@ -1027,7 +1034,7 @@ msh_ready (int msgnum, int full)
 	Msgs[msgnum].m_start = pos1;
 	Msgs[msgnum].m_stop = pos2;
 
-	mp->msgstats[msgnum] &= ~VIRTUAL;
+	unset_virtual (mp, msgnum);
     }
 #endif /* BPOP */
 
