@@ -423,7 +423,7 @@ burst (struct Msg *smsgs, int msgnum, int inplace, int quietsw, int verbosw)
 		free (Msgs[j].m_scanl);
 		Msgs[j].m_scanl = NULL;
 	    }
-	    mp->msgstats[i] = mp->msgstats[j];
+	    copy_msg_flags (mp, i, j);
 	}
 
     if (Msgs[msgnum].m_bboard_id == 0)
@@ -441,7 +441,7 @@ burst (struct Msg *smsgs, int msgnum, int inplace, int quietsw, int verbosw)
 	Msgs[i].m_start = smsgs[j].m_start;
 	Msgs[i].m_stop = smsgs[j].m_stop;
 	Msgs[i].m_scanl = NULL;
-	mp->msgstats[i] = mp->msgstats[msgnum];
+	copy_msg_flags (mp, i, msgnum);
     }
 
     return OK;
@@ -772,7 +772,7 @@ foldcmd (char **args)
 			free (Msgs[msgnum].m_scanl);
 			Msgs[msgnum].m_scanl = NULL;
 		    }
-		    mp->msgstats[hole] = mp->msgstats[msgnum];
+		    copy_msg_flags (mp, hole, msgnum);
 		    if (mp->curmsg == msgnum)
 			seq_setcur (mp, hole);
 		}
@@ -1124,12 +1124,12 @@ markcmd (char **args)
 {
     int addsw = 0, deletesw = 0, debugsw = 0;
     int listsw = 0, zerosw = 0, seqp = 0;
-    int msgp = 0, i, msgnum;
+    int msgp = 0, msgnum;
     char *cp, buf[BUFSIZ];
     char *seqs[NUMATTRS + 1], *msgs[MAXARGS];
 
     while ((cp = *args++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, markswit)) {
 		case AMBIGSW: 
 		    ambigsw (cp, markswit);
@@ -1183,12 +1183,13 @@ markcmd (char **args)
 		    zerosw = 0;
 		    continue;
 	    }
+	}
 	if (*cp == '+' || *cp == '@') {
 	    advise (NULL, "sorry, no folders allowed!");
 	    return;
-	}
-	else
+	} else {
 	    msgs[msgp++] = cp;
+	}
     }
 
     if (!addsw && !deletesw && !listsw)
@@ -1245,21 +1246,17 @@ markcmd (char **args)
 		return;
     }
 
-#define empty(s) ((s) ? (s) : "")
-
+    /* Listing messages in sequences */
     if (listsw) {
-	if (!seqp) {
-	    for (i = 0; mp->msgattrs[i]; i++)
-		printf ("%s%s: %s\n", mp->msgattrs[i],
-			is_seq_private (mp, i) ? " (private)" : "",
-			empty(seq_list(mp, mp->msgattrs[i])));
-	} else {
+	if (seqp) {
+	    /* list the given sequences */
 	    for (seqp = 0; seqs[seqp]; seqp++)
-		printf ("%s: %s\n", seqs[seqp], empty(seq_list(mp, seqs[seqp])));
+		seq_print (mp, seqs[seqp]);
+	} else {
+	    /* else list them all */
+	    seq_printall (mp);
 	}
 
-#undef empty
-
 	interrupted = 0;
 	if (debugsw)
 	    for (msgnum = mp->lowsel;
@@ -1985,8 +1982,8 @@ rmm (void)
 
     for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
 	if (is_selected (mp, msgnum)) {
-	    mp->msgstats[msgnum] |= DELETED;
-	    mp->msgstats[msgnum] &= ~EXISTS;
+	    set_deleted (mp, msgnum);
+	    unset_exists (mp, msgnum);
 #ifdef	MPOP
 #ifdef	BPOP
 	    if (pmsh && pop_dele (msgnum) != OK)
@@ -2221,7 +2218,7 @@ scancmd (char **args)
 #ifdef	BPOP
 		if (p_optim
 		        && optim
-			&& (mp->msgstats[msgnum] & VIRTUAL)
+			&& is_virtual (mp, msgnum)
 		        && pop_command ("LIST %d", msgnum) == OK
 			&& (cp = strchr(response, '#'))
 		        && *++cp) {
