@@ -471,7 +471,7 @@ pmatches (FILE *fp, int msgnum, long start, long stop)
 static void
 PRaction (struct nexus *n, int level)
 {
-    register int    i;
+    register int i;
 
     for (i = 0; i < level; i++)
 	fprintf (stderr, "| ");
@@ -504,7 +504,7 @@ PRaction (struct nexus *n, int level)
 		dasctime (&n->n_tws, TW_NULL));
 	return;
     }
-    fprintf (stderr, "UNKNOWN(0x%x)\n", (*n->n_action));
+    fprintf (stderr, "UNKNOWN(0x%x)\n", (unsigned int) (*n->n_action));
 }
 
 
