@@ -1833,6 +1833,10 @@ p_refile (char *file)
 }
 
 
+/*
+ * Call the `fileproc' to add the file to the folder.
+ */
+
 static void
 fcc (char *file, char *folder)
 {
@@ -1846,6 +1850,7 @@ fcc (char *file, char *folder)
 
     for (i = 0; (child_id = fork ()) == NOTOK && i < 5; i++)
 	sleep (5);
+
     switch (child_id) {
 	case NOTOK: 
 	    if (!verbose)
@@ -1855,8 +1860,11 @@ fcc (char *file, char *folder)
 	    break;
 
 	case OK: 
+	    /* see if we need to add `+' */
 	    sprintf (fold, "%s%s",
 		    *folder == '+' || *folder == '@' ? "" : "+", folder);
+
+	    /* now exec the fileproc */
 	    execlp (fileproc, r1bindex (fileproc, '/'),
 		    "-link", "-file", file, fold, NULL);
 	    _exit (-1);
@@ -1867,10 +1875,10 @@ fcc (char *file, char *folder)
 		    fprintf (stderr, "  %sFcc %s: ",
 			    msgstate == RESENT ? "Resent-" : "", folder);
 		pidstatus (status, verbose ? stdout : stderr, NULL);
-	    }
-	    else
+	    } else {
 		if (verbose)
 		    printf ("folder ok\n");
+	    }
     }
 
     fflush (stdout);
