@@ -84,17 +84,17 @@ main (int argc, char **argv)
 #endif
     invo_name = r1bindex (argv[0], '/');
     mts_init (invo_name);
-    if ((cp = context_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name))) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, switches);
@@ -145,6 +145,7 @@ main (int argc, char **argv)
                     continue;
 
 	    }
+	}
 	vec[vecp++] = cp;
     }
     vec[vecp] = 0;
@@ -175,7 +176,7 @@ alrmser (int i)
     SIGNAL (SIGALRM, alrmser);
 #endif
 
-    longjmp (myctx, DONE);
+    longjmp (myctx, 1);
 }
 
 
@@ -183,7 +184,7 @@ static int
 message_fd (char **vec)
 {
     pid_t child_id;
-    int bytes, fd;
+    int bytes, fd, seconds;
     char tmpfil[BUFSIZ];
     struct stat st;
 
@@ -201,14 +202,28 @@ message_fd (char **vec)
 	if (!setjmp (myctx)) {
 	    SIGNAL (SIGALRM, alrmser);
 	    bytes = fstat(fileno (stdin), &st) != NOTOK ? (int) st.st_size : 100;
-	    if (bytes <= 0)
-		bytes = 100;
-	    alarm ((unsigned) (bytes * 60 + 300));
+
+	    /* amount of time to wait depends on message size */
+	    if (bytes <= 100) {
+		/* give at least 5 minutes */
+		seconds = 300;
+	    } else if (bytes >= 90000) {
+		/* but 30 minutes should be long enough */
+		seconds = 1800;
+	    } else {
+		seconds = (bytes / 60) + 300;
+	    }
+	    alarm ((unsigned int) seconds);
 	    pidwait(child_id, OK);
 	    alarm (0);
+
 	    if (fstat (fd, &st) != NOTOK && st.st_size > (off_t) 0)
 		return fd;
 	} else {
+	    /*
+	     * Ruthlessly kill the child and anything
+	     * else in its process group.
+	     */
 	    KILLPG(child_id, SIGKILL);
 	}
 	close (fd);
