@@ -82,7 +82,7 @@ main (int argc, char **argv)
     argp = arguments;
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, switches);
@@ -142,6 +142,7 @@ main (int argc, char **argv)
 		    rmmproc = NULL;
 		    continue;
 	    }
+	}
 	if (*cp == '+' || *cp == '@') {
 	    if (foldp > NFOLDERS)
 		adios (NULL, "only %d folders allowed!", NFOLDERS);
@@ -162,6 +163,9 @@ main (int argc, char **argv)
 	files[filep++] = cp;
 #endif /* WHATNOW */
 
+    /*
+     * We are refiling a file to the folders
+     */
     if (filep > 0) {
 	if (folder || msgp)
 	    adios (NULL, "use -file or some messages, not both");
