@@ -39,9 +39,9 @@ static struct swit switches[] = {
 #define	FORMSW                11
     { "form formfile", 0 },
 #define	FRMTSW                12
-    { "format", -5 },
+    { "format", 5 },
 #define	NFRMTSW               13
-    { "noformat", -7 },
+    { "noformat", 7 },
 #define	INPLSW                14
     { "inplace", 0 },
 #define	NINPLSW               15
@@ -118,15 +118,14 @@ static struct swit aqrl[] = {
 short ccto = CCDFLT;		/* global for replsbr */
 short cccc = CCDFLT;
 short ccme = CCDFLT;
-short format = 1;
 short outputlinelen = OUTPUTLINELEN;
 short querysw = 0;
 
-extern int mime;		/* include original as MIME part */
+int mime = 0;			/* include original as MIME part */
+char *form   = NULL;		/* form (components) file        */
+char *filter = NULL;		/* message filter file           */
+char *fcc    = NULL;		/* folders to add to Fcc: header */
 
-char *fcc = NULL;		/* global for replsbr */
-char *filter = NULL;
-char *form = NULL;
 
 /*
  * prototypes
@@ -156,17 +155,17 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = context_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name))) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, switches);
@@ -254,10 +253,11 @@ main (int argc, char **argv)
 		    continue;
 
 		case FRMTSW: 
-		    format++;
+		    filter = getcpy (etcpath (mhlreply));
+		    mime = 0;
 		    continue;
 		case NFRMTSW: 
-		    format = 0;
+		    filter = NULL;
 		    continue;
 
 		case INPLSW: 
@@ -310,17 +310,18 @@ main (int argc, char **argv)
 		    isdf = NOTOK;
 		    continue;
 	    }
+	}
 	if (*cp == '+' || *cp == '@') {
 	    if (folder)
 		adios (NULL, "only one folder at a time!");
 	    else
 		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
-	}
-	else
+	} else {
 	    if (msg)
 		adios (NULL, "only one message at a time!");
 	    else
 		msg = cp;
+	}
     }
 
     cwd = getcpy (pwd ());
@@ -330,14 +331,19 @@ main (int argc, char **argv)
     if (file && (msg || folder))
 	adios (NULL, "can't mix files and folders/msgs");
 
-try_it_again: ;
-#ifndef MHE
-    strcpy (drft, m_draft (dfolder, dmsg, NOUSE, &isdf));
-    if (stat (drft, &st) != NOTOK) {
-#else /* MHE */
+try_it_again:;
+
+#ifdef MHE
     strcpy (drft, buildsw ? m_maildir ("reply")
 			  : m_draft (dfolder, NULL, NOUSE, &isdf));
+
+    /* Check if a draft exists */
     if (!buildsw && stat (drft, &st) != NOTOK) {
+#else
+    strcpy (drft, m_draft (dfolder, dmsg, NOUSE, &isdf));
+
+    /* Check if a draft exists */
+    if (stat (drft, &st) != NOTOK) {
 #endif /* MHE */
 	printf ("Draft \"%s\" exists (%ld bytes).", drft, st.st_size);
 	for (i = LISTDSW; i != YESW;) {
@@ -366,46 +372,54 @@ try_it_again: ;
     }
 
     if (file) {
-	anot = 0;
-	goto go_to_it;
+	/*
+	 * We are replying to a file.
+	 */
+	anot = 0;	/* we don't want to annotate a file */
+    } else {
+	/*
+	 * We are replying to a message.
+	 */
+	if (!msg)
+	    msg = "cur";
+	if (!folder)
+	    folder = getfolder (1);
+	maildir = m_maildir (folder);
+
+	if (chdir (maildir) == NOTOK)
+	    adios (maildir, "unable to change directory to");
+
+	/* read folder and create message structure */
+	if (!(mp = folder_read (folder)))
+	    adios (NULL, "unable to read folder %s", folder);
+
+	if (mp->hghmsg == 0)
+	    adios (NULL, "no messages in %s", folder);
+
+	/* parse the message range/sequence/name and set SELECTED */
+	if (!m_convert (mp, msg))
+	    done (1);
+	seq_setprev (mp);	/* set the previous-sequence */
+
+	if (mp->numsel > 1)
+	    adios (NULL, "only one message at a time!");
+
+	context_replace (pfolder, folder);	/* update current folder   */
+	seq_setcur (mp, mp->lowsel);	/* update current message  */
+	seq_save (mp);			/* synchronize sequences   */
+	context_save ();			/* save the context file   */
     }
 
-    if (!msg)
-	msg = "cur";
-    if (!folder)
-	folder = getfolder (1);
-    maildir = m_maildir (folder);
-
-    if (chdir (maildir) == NOTOK)
-	adios (maildir, "unable to change directory to");
-
-    /* read folder and create message structure */
-    if (!(mp = folder_read (folder)))
-	adios (NULL, "unable to read folder %s", folder);
-
-    if (mp->hghmsg == 0)
-	adios (NULL, "no messages in %s", folder);
-
-    /* parse the message range/sequence/name and set SELECTED */
-    if (!m_convert (mp, msg))
-	done (1);
-    seq_setprev (mp);	/* set the previous-sequence */
-
-    if (mp->numsel > 1)
-	adios (NULL, "only one message at a time!");
-
-    context_replace (pfolder, folder);	/* update current folder   */
-    seq_setcur (mp, mp->lowsel);	/* update current message  */
-    seq_save (mp);			/* synchronize sequences   */
-    context_save ();			/* save the context file   */
-
-go_to_it: ;
     msg = file ? file : getcpy (m_name (mp->lowsel));
 
     if ((in = fopen (msg, "r")) == NULL)
 	adios (msg, "unable to open");
 
-    replout (in, msg, drft, mp);
+    /* find form (components) file */
+    if (!form)
+	form = etcpath (replcomps);
+
+    replout (in, msg, drft, mp, mime, form, filter, fcc);
     fclose (in);
 
     if (nwhat)
