@@ -13,14 +13,8 @@
 extern short ccto;		/* from repl.c */
 extern short cccc;
 extern short ccme;
-extern short format;
 extern short outputlinelen;
 extern short querysw;
-extern int mime;		/* include original as MIME part */
-
-extern char *fcc;
-extern char *filter;
-extern char *form;
 
 static int dftype=0;
 
@@ -41,9 +35,9 @@ static struct mailname mq = { NULL };
 
 static struct format *fmt;
 
-static int	ncomps = 0;		/* # of interesting components */
-static char	**compbuffers = 0; 	/* buffers for component text */
-static struct comp **used_buf = 0;	/* stack for comp that use buffers */
+static int ncomps = 0;			/* # of interesting components */
+static char **compbuffers = NULL; 	/* buffers for component text */
+static struct comp **used_buf = NULL;	/* stack for comp that use buffers */
 
 static int dat[5];			/* aux. data for format routine */
 
@@ -67,11 +61,12 @@ static char *addrcomps[] = {
  * static prototypes
  */
 static int insert (struct mailname *);
-static void replfilter (FILE *, FILE *);
+static void replfilter (FILE *, FILE *, char *);
 
 
 void
-replout (FILE *inb, char *msg, char *drft, struct msgs *mp)
+replout (FILE *inb, char *msg, char *drft, struct msgs *mp, int mime,
+	 char *form, char *filter, char *fcc)
 {
     register int state;
     register int i;
@@ -91,20 +86,20 @@ replout (FILE *inb, char *msg, char *drft, struct msgs *mp)
     if ((out = fopen (drft, "w")) == NULL)
 	adios (drft, "unable to create");
 
-    cp = new_fs (form ? form : replcomps, NULL, NULL);
+    cp = new_fs (form, NULL, NULL);
     format_len = strlen (cp);
     ncomps = fmt_compile (cp, &fmt) + 1;
-    if ((nxtbuf = compbuffers = (char **)
-	    calloc((size_t) ncomps, sizeof(char *))) == (char **)NULL)
+    if (!(nxtbuf = compbuffers = (char **)
+	    calloc((size_t) ncomps, sizeof(char *))))
 	adios (NULL, "unable to allocate component buffers");
-    if ((savecomp = used_buf = (struct comp **)
-	    calloc((size_t) (ncomps+1), sizeof(struct comp *)))
-	    == (struct comp **)NULL)
+    if (!(savecomp = used_buf = (struct comp **)
+	    calloc((size_t) (ncomps+1), sizeof(struct comp *))))
 	adios (NULL, "unable to allocate component buffer stack");
     savecomp += ncomps + 1;
-    *--savecomp = (struct comp *)0;	/* point at zero'd end minus 1 */
+    *--savecomp = NULL;		/* point at zero'd end minus 1 */
+
     for (i = ncomps; i--; )
-	if ((*nxtbuf++ = malloc( SBUFSIZ )) == NULL)
+	if (!(*nxtbuf++ = malloc(SBUFSIZ)))
 	    adios (NULL, "unable to allocate component buffer");
 
     nxtbuf = compbuffers;		/* point at start */
@@ -196,11 +191,12 @@ replout (FILE *inb, char *msg, char *drft, struct msgs *mp)
 		adios (NULL, "m_getfld() returned %d", state);
 	}
     }
+
     /*
      * format and output the header lines.
      */
 finished:
-    /* if there's a "subject" component, strip any "re:"s off it */
+    /* if there's a "subject" component, strip any "Re:"s off it */
     FINDCOMP (cptr, "subject")
     if (cptr && (cp = cptr->c_text)) {
 	register char *sp = cp;
@@ -221,17 +217,21 @@ finished:
 	}
     }
     i = format_len + char_read + 256;
-    scanl = malloc ((unsigned)i + 2);
-    dat[0] = dat[1] = dat[2] = dat[4] = 0;
+    scanl = malloc ((size_t) i + 2);
+    dat[0] = 0;
+    dat[1] = 0;
+    dat[2] = 0;
     dat[3] = outputlinelen;
+    dat[4] = 0;
     fmt_scan (fmt, scanl, i, dat);
     fputs (scanl, out);
     if (badaddrs) {
 	fputs ("\nrepl: bad addresses:\n", out);
 	fputs ( badaddrs, out);
     }
+
     if (filter) {
-	replfilter (inb, out);
+	replfilter (inb, out, filter);
     }
 #ifdef MIME
     else {
@@ -397,8 +397,12 @@ insert (struct mailname *np)
 }
 
 
+/*
+ * Call the mhlproc
+ */
+
 static void
-replfilter (FILE *in, FILE *out)
+replfilter (FILE *in, FILE *out, char *filter)
 {
     int	pid;
     char *mhl;
@@ -412,7 +416,7 @@ replfilter (FILE *in, FILE *out)
     mhl = r1bindex (mhlproc, '/');
 
     rewind (in);
-    lseek (fileno(in), (off_t)0, SEEK_SET);
+    lseek (fileno(in), (off_t) 0, SEEK_SET);
     fflush (out);
 
     switch (pid = vfork ()) {
