@@ -103,7 +103,6 @@ static struct swit anyl[] = {
 extern int debugsw;		/* from sendsbr.c */
 extern int forwsw;
 extern int inplace;
-extern int mime;
 extern int pushsw;
 extern int splitsw;
 extern int unique;
@@ -115,6 +114,8 @@ extern char *distfile;
 
 extern int   errno;
 
+int mime = 0;		/* process as MIME */
+
 
 int
 main (int argc, char **argv)
