@@ -490,7 +490,7 @@ rename_chain (struct msgs *mp, struct smsg **mlist, int msg, int endmsg)
 	if (rename (oldname, newname) == NOTOK)
 	    adios (newname, "unable to rename %s to", oldname);
 
-	mp->msgstats[new] = mp->msgstats[old];
+	copy_msg_flags (mp, new, old);
 	if (mp->curmsg == old)
 	    seq_setcur (mp, new);
 
@@ -506,7 +506,8 @@ rename_chain (struct msgs *mp, struct smsg **mlist, int msg, int endmsg)
 static void
 rename_msgs (struct msgs *mp, struct smsg **mlist)
 {
-    int i, j, old, new, stats;
+    int i, j, old, new;
+    seqset_t tmpset;
     char f1[BUFSIZ], tmpfil[BUFSIZ];
     struct smsg *sp;
 
@@ -534,13 +535,13 @@ rename_msgs (struct msgs *mp, struct smsg **mlist)
 
 	if (rename (f1, tmpfil) == NOTOK)
 	    adios (tmpfil, "unable to rename %s to ", f1);
-	stats = mp->msgstats[old];
+	get_msg_flags (mp, &tmpset, old);
 
 	rename_chain (mp, mlist, j, i);
 	if (rename (tmpfil, m_name(new)) == NOTOK)
 	    adios (m_name(new), "unable to rename %s to", tmpfil);
 
-	mp->msgstats[new] = stats;
+	set_msg_flags (mp, &tmpset, new);
 	mp->msgflags |= SEQMOD;
     }
 }
