@@ -2,8 +2,8 @@
 /*
  * spost.c -- feed messages to sendmail
  *
- * This is a simpler, faster, replacement for "post" for use when "sendmail"
- * is the transport system.  It is currently only used when BERK is defined.
+ * This is a simpler, faster, replacement for "post" for use
+ * when "sendmail" is the transport system.
  *
  * $Id$
  */
@@ -118,7 +118,7 @@ static struct headers NHeaders[] = {
     { "Bcc",         HADR|HTRY|HBCC|HNIL, MINV },
     { "Message-Id",  HBAD,                0 },
     { "Fcc",         HFCC,                0 },
-    NULL
+    { NULL,          0,                   0 }
 };
 
 static struct headers RHeaders[] = {
@@ -134,7 +134,7 @@ static struct headers RHeaders[] = {
     { "Resent-Fcc",        HFCC,           0 },
     { "Reply-To",          HADR,           0 },
     { "Fcc",               HIGN,           0 },
-    NULL
+    { NULL,                0,              0 }
 };
 
 
@@ -182,10 +182,13 @@ static int get_header (char *, struct headers *);
 static void putadr (char *, struct mailname *);
 static int putone (char *, int, int);
 static void insert_fcc (struct headers *, char *);
-static void make_bcc_file (void);
 static void file (char *);
 static void fcc (char *, char *);
+
+#if 0
 static void die (char *, char *, ...);
+static void make_bcc_file (void);
+#endif
 
 
 int
@@ -202,13 +205,13 @@ main (int argc, char **argv)
 #endif
     invo_name = r1bindex (argv[0], '/');
     mts_init (invo_name);
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	argp = copyip (brkstring (cp, " ", "\n"), arguments);
 	copyip (argv+1, argp);
 	argp = arguments;
     }
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
@@ -441,9 +444,8 @@ main (int argc, char **argv)
 static void
 putfmt (char *name, char *str, FILE *out)
 {
-    int count, grp, i, keep;
-    char *cp, *pp, *qp, namep[BUFSIZ];
-    struct mailname *mp, *np;
+    int i;
+    char *cp, *pp;
     struct headers *hdr;
 
     while (*str == ' ' || *str == '\t')
@@ -468,7 +470,7 @@ putfmt (char *name, char *str, FILE *out)
 	subject = subject ? add (str, add ("\t", subject)) : getcpy (str);
 
     if (hdr->flags & HFCC) {
-	if (cp = strrchr(str, '\n'))
+	if ((cp = strrchr(str, '\n')))
 	    *cp = 0;
 	for (cp = pp = str; cp = strchr(pp, ','); pp = cp) {
 	    *cp++ = 0;
@@ -496,7 +498,7 @@ putfmt (char *name, char *str, FILE *out)
 	    register struct mailname *f = 0;
 	    register struct mailname *mp = 0;
 
-	    while (cp = getname( str ) ) {
+	    while ((cp = getname(str))) {
 		mp = getm( cp, NULL, 0, AD_HOST, NULL);
 		if (f == 0) {
 		    f = mp;
@@ -611,7 +613,7 @@ putadr (char *name, struct mailname *nl)
 		linepos = putone( mp->m_text, linepos, namelen );
 	    else
 		/* an alias - expand it */
-		while (cp = getname(cp) ) {
+		while ((cp = getname(cp))) {
 		    if (linepos > MAX_SM_FIELD) {
 			    fprintf (out, "\n%s: ", name);
 			    linepos = namelen;
@@ -681,7 +683,7 @@ insert_fcc (struct headers *hdr, char *pp)
     fccfold[fccind++] = getcpy (cp);
 }
 
-#ifdef notdef
+#if 0
 /* BCC GENERATION */
 
 static void
@@ -743,7 +745,7 @@ make_bcc_file (void)
     fprintf (out, "\n------- End of Blind-Carbon-Copy\n");
     fclose (out);
 }
-#endif	/* notdef */
+#endif	/* if 0 */
 
 /* FCC INTERACTION */
 
@@ -792,7 +794,7 @@ fcc (char *file, char *folder)
 	    _exit (-1);
 
 	default: 
-	    if (status = pidwait(child_id, OK)) {
+	    if ((status = pidwait(child_id, OK))) {
 		if (!verbose)
 		    fprintf (stderr, "  %sFcc %s: ",
 			    msgstate == resent ? "Resent-" : "", folder);
@@ -805,6 +807,8 @@ fcc (char *file, char *folder)
 }
 
 
+#if 0
+
 /*
  * TERMINATION
  */
@@ -820,3 +824,4 @@ die (char *what, char *fmt, ...)
 
     done (1);
 }
+#endif
